package
Version:
v0.6.0
Opens a new window with list of versions in this module.
Published: Mar 29, 2025
License: BSD-3-Clause
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Address string `yaml:"address"`
Network string `yaml:"network"`
SSL *SSL `yaml:"ssl,omitempty"`
}
type SSL struct {
Certs []listen.Certificate `yaml:"certs,omitempty"`
NextProtos []string `yaml:"next_protos,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.